# YT_Streamer
```diff
+ This is a simple script that can stream audio from youtube based on search results you give.
@@ EDIT: You can now install this via pip @@
Gstreamer bindings for python need to be installed on linux for it to run.
```
Works on linux.
Not tested on Windows and Mac.


```pip3 install ytstreamer```

